@@ -1,8 +1,8 @@
-/*$Id: formail.h,v 1.13 1994/09/29 18:43:44 berg Exp $*/
+/*$Id: formail.h,v 1.15 1999/02/14 04:43:31 srb Exp $*/
 
 #define Bsize		128
 
-#define NAMEPREFIX	"formail: "
+#define FORMAILN	"formail"
 #define HEAD_DELIMITER	':'
 
 #define Re		(re+1)
@@ -15,26 +15,27 @@
 
 struct saved {const char*const headr;const int lenr;int rexl;char*rexp;};
 
-extern const char binsh[],sfolder[],couldntw[];
+extern const char binsh[],sfolder[],couldntw[],formailn[];
 extern char ffileno[];
 extern int errout,oldstdout,quiet,zap,buflast,lenfileno;
 extern long initfileno;
 extern pid_t child;
+extern int childlimit;
 extern unsigned long rhash;
 extern FILE*mystdout;
 extern int nrskip,nrtotal,retval;
 extern size_t buflen,buffilled;
-extern long totallen;
+extern long Totallen;
 extern char*buf,*logsummary;
 
 extern struct field
  { size_t id_len;
-   union {size_t utot_len;struct field**ufld_ref;} len_fld;
+   union {size_t uTot_len;struct field**ufld_ref;} len_fld;
    struct field*fld_next;
    char fld_text[255];
  }*rdheader,*xheader,*Xheader,*uheader,*Uheader;
 
-#define tot_len len_fld.utot_len
+#define Tot_len len_fld.uTot_len
 #define fld_ref len_fld.ufld_ref
 
 int
