@@ -8,7 +8,7 @@
  ************************************************************************/
 #ifdef RCS
 static /*const*/char rcsid[]=
- "$Id: misc.c,v 1.99.2.10 2001/07/16 08:04:15 guenther Exp $";
+ "$Id: misc.c,v 1.117 2001/06/26 08:46:48 guenther Exp $";
 #endif
 #include "procmail.h"
 #include "acommon.h"
@@ -23,31 +23,14 @@ static /*const*/char rcsid[]=
 #include "mcommon.h"
 #include "goodies.h"
 #include "locking.h"
-#include "../patchlevel.h"
 #include "comsat.h"
 #include "mailfold.h"
 #include "lastdirsep.h"
+#include "memblk.h"
 #include "authenticate.h"
+#include "variables.h"
 #include "shell.h"
 
-struct varval strenvvar[]={{"LOCKSLEEP",DEFlocksleep},
- {"LOCKTIMEOUT",DEFlocktimeout},{"SUSPEND",DEFsuspend},
- {"NORESRETRY",DEFnoresretry},{"TIMEOUT",DEFtimeout},{"VERBOSE",DEFverbose},
- {"LOGABSTRACT",DEFlogabstract}};
-struct varstr strenstr[]={{"SHELLMETAS",DEFshellmetas},{"LOCKEXT",DEFlockext},
- {"MSGPREFIX",DEFmsgprefix},{"TRAP",empty},
- {"SHELLFLAGS",DEFshellflags},{"DEFAULT",DEFdefault},{"SENDMAIL",DEFsendmail},
- {"SENDMAILFLAGS",DEFflagsendmail},{"PROCMAIL_VERSION",PM_VERSION}};
-
-#define MAXvarvals	 maxindex(strenvvar)
-#define MAXvarstrs	 maxindex(strenstr)
-
-const char lastfolder[]="LASTFOLDER",maildir[]="MAILDIR",slinebuf[]="LINEBUF";
-static const char scomsat[]="COMSAT";
-int didchd;
-char*globlock;
-static time_t oldtime;
-static int fakedelivery;
 		       /* line buffered to keep concurrent entries untangled */
 void elog(newt)const char*const newt;
 { int lnew;size_t i;static size_t lold,lmax;static char*old;
@@ -97,6 +80,7 @@ void shutdesc P((void))
 { rclose(savstdout);closelog();closerc();
 }
 
+/* On systems with `capabilities', setuid/setgid can fail for root! */
 void checkroot(c,Xid)const int c;const unsigned long Xid;
 { uid_t eff;
   if((eff=geteuid())!=ROOT_uid&&getuid()!=ROOT_uid)
@@ -108,14 +92,15 @@ void checkroot(c,Xid)const int c;const unsigned long Xid;
 }
 
 void setids P((void))
-{ if(rcstate!=rc_NORMAL)
+{ if(privileged)
    { if(setRgid(gid)&&	/* due to these !@#$%^&*() POSIX semantics, setgid() */
       setgid(gid))	   /* sets the saved gid as well; we can't use that! */
 	checkroot('g',(unsigned long)gid);	 /* did setgid fail as root? */
      setruid(uid);
      if(setuid(uid))				     /* "This cannot happen" */
 	checkroot('u',(unsigned long)uid);			/* Whoops... */
-     setegid(gid);rcstate=rc_NORMAL;
+     setegid(gid);
+     privileged=0;
 #if !DEFverbose
      verbose=0;			/* to avoid peeking in rcfiles using SIGUSR1 */
 #endif
@@ -149,6 +134,34 @@ void readerr(file)const char*const file;
 { nlog("Couldn't read");logqnl(file);
 }
 
+int buildpath(name,path,file)const char*name,*const path,*const file;
+{ static const char toolong[]=" path too long",
+   notabsolute[]=" is not an absolute path";
+  sgetcp=path;
+  if(readparse(buf,sgetc,2,0))
+   { syslog(LOG_CRIT,"%s%s for LINEBUF for uid \"%lu\"\n",name,toolong,
+      (unsigned long)uid);
+bad: nlog(name);elog(toolong);elog(newline);
+     return 1;
+   }
+  if(!strchr(dirsep,buf[0]))
+   { nlog(name);elog(notabsolute);elog(newline);
+     syslog(LOG_CRIT,"%s%s for uid \"%lu\"\n",name,notabsolute,
+      (unsigned long)uid);
+     return 1;
+   }
+  if(file)
+   { char*chp=strchr(buf,'\0');
+     if(chp-buf+strlen(file)+2>linebuf)			  /* +2 for / and \0 */
+      { name="full rcfile";		  /* this should be passed in... XXX */
+	goto bad;
+      }
+     *chp++= *MCDIRSEP_;
+     strcpy(chp,file);				      /* append the filename */
+   }
+  return 0;
+}
+
 void verboff P((void))
 { verbose=0;
 #ifdef SIGUSR1
@@ -168,6 +181,8 @@ void yell(a,b)const char*const a,*const b;		/* log if VERBOSE=on */
      nlog(a),logqnl(b);
 }
 
+static time_t oldtime;
+
 void newid P((void))
 { thepid=getpid();oldtime=0;
 }
@@ -202,7 +217,7 @@ int nextrcfile P((void))	/* next rcfile specified on the command line */
   while(p= *gargv)
    { gargv++;
      if(!strchr(p,'='))
-      { if(strlen(p)>linebuf-XTRAlinebuf-1)
+      { if(strlen(p)>linebuf-1)
 	 { nlog("Excessively long rcfile path skipped\n");
 	   continue;
 	 }
@@ -214,6 +229,18 @@ int nextrcfile P((void))	/* next rcfile specified on the command line */
   return 0;
 }
 
+char*tstrdup(a)const char*const a;
+{ int i;
+  i=strlen(a)+1;
+  return tmemmove(malloc(i),a,i);
+}
+
+char*cstr(a,b)char*const a;const char*const b;	/* dynamic buffer management */
+{ if(a)
+     free(a);
+  return tstrdup(b);
+}
+
 void onguard P((void))
 { lcking|=lck_DELAYSIG;
 }
@@ -244,6 +271,8 @@ static void sterminate P((void))
    }
 }
 
+int fakedelivery;
+
 void Terminate P((void))
 { ignoreterm();
   if(getpid()==thepid)
@@ -276,280 +305,25 @@ void suspend P((void))
 { ssleep((unsigned)suspendv);
 }
 
-void*app_val_(sp)struct dyna_long*const sp;
-{ if(sp->filled==sp->tspace)			    /* growth limit reached? */
-   { size_t len=(sp->tspace+=4)*sizeof*sp->vals;
-     sp->vals=sp->vals?realloc(sp->vals,len):malloc(len);	   /* expand */
-   }
-  return &sp->vals[sp->filled++];			     /* append to it */
-}
-
-int alphanum(c)const unsigned c;
-{ return numeric(c)||c-'a'<='z'-'a'||c-'A'<='Z'-'A'||c=='_';
-}
-
-char*pmrc2buf P((void))
-{ sgetcp=pmrc;
-  if(readparse(buf,sgetc,2))
-     buf[0]='\0';
-  return buf;
-}
-
-void setmaildir(newdir)const char*const newdir;		    /* destroys buf2 */
-{ char*chp;
-  didchd=1;*(chp=strcpy(buf2,maildir)+STRLEN(maildir))='=';
-  strcpy(++chp,newdir);sputenv(buf2);
-}
-
-void setoverflow P((void))
-{ sputenv("PROCMAIL_OVERFLOW=yes");
-}
-
-void srequeue P((void))
+static void srequeue P((void))
 { retval=EX_TEMPFAIL;sterminate();
 }
 
-void slose P((void))
+static void slose P((void))
 { fakedelivery=2;sterminate();
 }
 
-void sbounce P((void))
+static void sbounce P((void))
 { retval=EX_CANTCREAT;sterminate();
 }
 
-void setdef(name,contents)const char*const name,*const contents;
-{ strcat(strcat(strcpy((char*)(sgetcp=buf2),name),"="),contents);
-  if(!readparse(buf,sgetc,2))
-     sputenv(buf);
+void setupsigs P((void))
+{ qsignal(SIGTERM,srequeue);qsignal(SIGINT,sbounce);
+  qsignal(SIGHUP,sbounce);qsignal(SIGQUIT,slose);
+  signal(SIGALRM,(void(*)())ftimeout);
 }
 
-void metaparse(p)const char*p;				    /* result in buf */
-{ if(sh=!!strpbrk(p,shellmetas))
-     strcpy(buf,p);			 /* copy literally, shell will parse */
-  else
-   { sgetcp=p=tstrdup(p);
-     if(readparse(buf,sgetc,0)				/* parse it yourself */
-#ifndef GOT_bin_test
-	||!strcmp(test,buf)
-#endif
-	)
-	strcpy(buf,p),sh=1;		   /* oops, overflow or `test' found */
-     free((char*)p);
-   }
-}
-
-void concatenate(p)register char*p;
-{ while(p!=Tmnate)			  /* concatenate all other arguments */
-   { while(*p++);
-     p[-1]=' ';
-   }
-  *p=p[-1]='\0';
-}
-
-char*tstrdup(a)const char*const a;
-{ int i;
-  i=strlen(a)+1;
-  return tmemmove(malloc(i),a,i);
-}
-
-const char*tgetenv(a)const char*const a;
-{ const char*b;
-  return (b=getenv(a))?b:empty;
-}
-
-char*cstr(a,b)char*const a;const char*const b;	/* dynamic buffer management */
-{ if(a)
-     free(a);
-  return tstrdup(b);
-}
-
-void setlastfolder(folder)const char*const folder;
-{ char*chp;size_t len;
-  setlfcs(folder);
-  len=STRLEN(lastfolder)+2+strlen(folder);
-  strlcpy(chp=malloc(len),lastfolder,len);
-  strlcat(chp,"=",len);
-  strlcat(chp,folder,len);
-  sputenv(chp);free(chp);
-}
-
-char*gobenv(chp,end)char*chp,*end;
-{ int found,i;
-  found=0;end--;
-  if(alphanum(i=getb())&&!numeric(i))
-     for(found=1;*chp++=i,chp<end&&alphanum(i=getb()););
-  *chp='\0';ungetb(i);
-  if(chp==end)							 /* overflow */
-   { nlog(exceededlb);setoverflow();
-     return end+1;
-   }
-  switch(i)
-   { case ' ':case '\t':case '\n':case '=':
-	if(found)
-	   return chp;
-   }
-  return 0;
-}
-
-int asenvcpy(src)char*src;
-{ const char*chp;
-  if(chp=strchr(src,'='))			     /* is it an assignment? */
-    /*
-     *	really change the uid now, since it would not be safe to
-     *	evaluate the extra command line arguments otherwise
-     */
-   { size_t len=chp++-src+1;			      /* variable name + '=' */
-     erestrict=1;setids();				   /* always do this */
-     if(len>linebuf-XTRAlinebuf-1)			/* too long of name? */
-      { setoverflow();
-	nlog("Assignment to variable with excessively long name skipped\n");
-      }
-     else
-      { memcpy(buf,src,len);
-	src=buf+len;
-	if(chp=eputenv(chp,src))
-	 { src[-1]='\0';
-	   asenv(chp);
-	 }
-      }
-     return 1;
-   }
-  return 0;
-}
-
-void mallocbuffers(lineb,setenv)size_t lineb;int setenv;
-{ if(buf)
-   { free(buf);
-     free(buf2);
-   }
-  buf=malloc(lineb+XTRAlinebuf);buf2=malloc(lineb+XTRAlinebuf);
-  if(setenv)
-   { char*chp;
-     *(chp=strcpy(buf,slinebuf)+STRLEN(slinebuf))='=';
-     ultstr(0,lineb,chp+1);
-     sputenv(buf);
-   }
-}
-
-void asenvtext(chp)const char*const chp;
-{ int i=MAXvarstrs;
-  do						 /* several text assignments */
-     if(!strcmp(buf,strenstr[i].sname))
-	strenstr[i].sval=chp;
-  while(i--);
-}
-
-void asenv(chp)const char*const chp;
-{ static const char logfile[]="LOGFILE",Log[]="LOG",sdelivered[]="DELIVERED",
-   includerc[]="INCLUDERC",eumask[]="UMASK",dropprivs[]="DROPPRIVS",
-   shift[]="SHIFT",switchrc[]="SWITCHRC";
-  if(!strcmp(buf,slinebuf))
-   { long lineb;			 /* signed to catch negative numbers */
-     if((lineb=renvint(0L,chp))<MINlinebuf)
-	lineb=MINlinebuf;			       /* check minimum size */
-     mallocbuffers(linebuf=lineb,0);
-   }
-  else if(!strcmp(buf,maildir))
-     if(chdir(chp))
-	chderr(chp);
-     else
-	didchd=1;
-  else if(!strcmp(buf,logfile))
-     opnlog(chp);
-  else if(!strcmp(buf,Log))
-     elog(chp);
-  else if(!strcmp(buf,exitcode))
-     setxit=1;
-  else if(!strcmp(buf,lgname))
-     setlgcs(chp);
-  else if(!strcmp(buf,lastfolder))
-     setlfcs(chp);
-  else if(!strcmp(buf,scomsat))
-     setcomsat(chp);
-  else if(!strcmp(buf,shift))
-   { int i;
-     if((i=renvint(0L,chp))>0)
-      { if(i>crestarg)
-	   i=crestarg;
-	crestarg-=i;restargv+=i;		     /* shift away arguments */
-      }
-   }
-  else if(!strcmp(buf,dropprivs))			  /* drop privileges */
-   { if(renvint(0L,chp))
-      { if(verbose)
-	   nlog("Assuming identity of the recipient, VERBOSE=off\n");
-	setids();
-      }
-   }
-  else if(!strcmp(buf,sdelivered))			    /* fake delivery */
-   { if(renvint(0L,chp))				    /* is it really? */
-      { onguard();
-	if((thepid=sfork())>0)
-	   _exit(retvl2);			   /* parent: do not pass go */
-	if(!forkerr(thepid,procmailn))
-	   fakedelivery=1;
-	newid();offguard();
-      }
-   }
-  else if(!strcmp(buf,lockfile))
-     lockit(tstrdup((char*)chp),&globlock);
-  else if(!strcmp(buf,eumask))
-     doumask((mode_t)strtol(chp,(char**)0,8));
-  else if(!strcmp(buf,includerc))
-   { if(rc>=0)				 /* INCLUDERC and SWITCHRC only work */
-	pushrc(chp);					   /* inside rcfiles */
-   }					      /* and not on the command line */
-  else if(!strcmp(buf,switchrc))
-   { if(rc>=0)
-	changerc(chp);
-   }
-  else if(!strcmp(buf,host))
-   { const char*name;
-     if(strcmp(chp,name=hostname()))
-      { yell("HOST mismatched",name);
-	if(rc<0||!nextrcfile())			  /* if no rcfile opened yet */
-	   retval=EXIT_SUCCESS,Terminate();	  /* exit gracefully as well */
-	closerc();
-      }
-   }
-  else
-   { int i=MAXvarvals;
-     do					      /* several numeric assignments */
-	if(!strcmp(buf,strenvvar[i].name))
-	   strenvvar[i].val=renvint(strenvvar[i].val,chp);
-     while(i--);
-     asenvtext(chp);			    /* delegate the text assignments */
-   }
-}
-
-long renvint(i,env)const long i;const char*const env;
-{ const char*p;long t;
-  t=strtol(env,(char**)&p,10);			  /* parse like a decimal nr */
-  if(p==env)
-     for(;;p++)
-      { switch(*p)
-	 { case ' ':case '\t':case '\n':case '\v':case '\f':case '\r':
-	      continue;				  /* skip leading whitespace */
-	   case 'o':case 'O':
-	      if(!strnIcmp(p+1,"n",(size_t)1))
-	   case 'y':case 'Y':case 't':case 'T':case 'e':case 'E':
-		 t=1;
-	      else if(!strnIcmp(p+1,"ff",(size_t)2))
-	   case 'n':case 'N':case 'f':case 'F':case 'd':case 'D':
-		 t=0;
-	      else
-	   default:
-		 t=i;
-	      break;
-	   case 'a':case 'A':t=2;
-	      break;
-	 }
-	break;
-      }
-  return t;
-}
-
-void squeeze(target)char*target;
+static void squeeze(target)char*target;
 { int state;char*src;
   for(state=0,src=target;;target++,src++)
    { switch(*target= *src)
@@ -591,14 +365,6 @@ int enoughprivs(passinvk,euid,egid,uid,gid)const auth_identity*const passinvk;
    euid==uid&&egid==gid;
 }
 
-void initdefenv P((void))
-{ int i=MAXvarstrs;
-  do	   /* initialise all non-empty string variables into the environment */
-     if(*strenstr[i].sval)
-	setdef(strenstr[i].sname,strenstr[i].sval);
-  while(i--);
-}
-
 const char*newdynstring(adrp,chp)struct dynstring**const adrp;
  const char*const chp;
 { struct dynstring*curr;size_t len;
@@ -607,21 +373,24 @@ const char*newdynstring(adrp,chp)struct dynstring**const adrp;
   return curr->ename;
 }
 
-void rcst_nosgid P((void))
-{ if(!rcstate)
-     rcstate=rc_NOSGID;
+void*app_val_(sp,size)struct dyna_array*const sp;int size;
+{ if(sp->filled==sp->tspace)			    /* growth limit reached? */
+   { size_t len=(sp->tspace+=4)*size;
+     sp->vals=sp->vals?realloc(sp->vals,len):malloc(len);	   /* expand */
+   }
+  return &sp->vals[size*sp->filled++];			     /* append to it */
 }
 
 			     /* lifted out of main() to reduce main()'s size */
-int conditions(flags,prevcond,lastsucc,lastcond,nrcond)char flags[];
- const int prevcond,lastsucc,lastcond;int nrcond;
+int conditions(flags,prevcond,lastsucc,lastcond,skipping,nrcond)char flags[];
+ const int prevcond,lastsucc,lastcond,skipping;int nrcond;
 { char*chp,*chp2,*startchar;double score;int scored,i,skippedempty;
   long tobesent;static const char suppressed[]=" suppressed\n";
   score=scored=0;
   if(nrcond<0)		      /* assume appropriate default nr of conditions */
      nrcond=!flags[ALSO_NEXT_RECIPE]&&!flags[ALSO_N_IF_SUCC]&&!flags[ELSE_DO]&&
       !flags[ERROR_DO];
-  startchar=themail;tobesent=thebody-themail;
+  startchar=themail.p;tobesent=thebody-themail.p;
   if(flags[BODY_GREP])			       /* what needs to be egrepped? */
      if(flags[HEAD_GREP])
 	tobesent=filled;
@@ -629,10 +398,10 @@ int conditions(flags,prevcond,lastsucc,lastcond,nrcond)char flags[];
       { startchar=thebody;tobesent=filled-tobesent;
 	goto noconcat;
       }
-   if(!skiprc)
+   if(!skipping)
       concon(' ');
 noconcat:
-   i=!skiprc;						  /* init test value */
+   i=!skipping;						  /* init test value */
    if(flags[ERROR_DO])
     { i&=prevcond&&!lastsucc;
       if(flags[ELSE_DO])
@@ -685,10 +454,10 @@ copydone: { switch(*(sgetcp=buf2))
 	     { case '0':case '1':case '2':case '3':case '4':case '5':case '6':
 	       case '7':case '8':case '9':case '-':case '+':case '.':case ',':
 		{ char*chp3;double w;
-		  w=stod(buf2,(const char**)&chp3);chp2=chp3;
+		  w=strtod(buf2,&chp3);chp2=chp3;
 		  if(chp2>buf2&&*(chp2=skpspace(chp2))=='^')
 		   { double x;
-		     x=stod(chp2+1,(const char**)&chp3);
+		     x=strtod(chp2+1,&chp3);
 		     if(chp3>chp2+1)
 		      { if(score>=MAX32)
 			   goto skiptrue;
@@ -701,13 +470,13 @@ copydone: { switch(*(sgetcp=buf2))
 		  goto normalregexp;
 		}
 	       default:chp--;		     /* no special character, backup */
-		{ if(alphanum(*(chp2=chp)))
+		{ if(alphanum(*(chp2=chp))==1)
 		   { char*chp3;
 		     while(alphanum(*++chp2));
 		     if(!strncmp(chp3=skpspace(chp2),"??",2))
-		      { *chp2='\0';lstartchar=themail;
+		      { *chp2='\0';lstartchar=themail.p;
 			if(!chp[1])
-			 { ltobesent=thebody-themail;
+			 { ltobesent=thebody-themail.p;
 			   switch(*chp)
 			    { case 'B':lstartchar=thebody;
 				 ltobesent=filled-ltobesent;
@@ -798,7 +567,7 @@ jinregs:		regsp=regs;		/* start over and look again */
 		  break;
 		}
 	       case '$':*buf2='"';squeeze(chp);
-		  if(readparse(buf,sgetc,2)&&(i=0,1))
+		  if(readparse(buf,sgetc,2,0)&&(i=0,1))
 		     break;
 		  strcpy(buf2,skpspace(buf));
 		  goto copydone;
@@ -822,7 +591,7 @@ copyrest:	  strcpy(buf,chp2);
 		   break;
 	       case '>':case '<':
 		{ long pivot;
-		  if(readparse(buf,sgetc,2)&&(i=0,1))
+		  if(readparse(buf,sgetc,2,0)&&(i=0,1))
 		     break;
 		  ;{ char*chp3;
 		     pivot=strtol(buf+1,&chp3,10);chp=chp3;
