@@ -1,4 +1,4 @@
-/*$Id: network.h,v 1.6 1994/05/26 14:13:17 berg Exp $*/
+/*$Id: network.h,v 1.7 1997/04/02 03:15:41 srb Exp $*/
 
 #include <sys/socket.h>			/* socket() sendto() AF_INET
 					/* SOCK_DGRAM */
@@ -13,3 +13,9 @@
 #ifndef h_0addr_list
 #define h_0addr_list	h_addr_list[0]		      /* POSIX struct member */
 #endif
+
+#ifndef NO_const      /* since network.h is outside the autoconf const check */
+#ifdef const		    /* loop, we need this backcheck for some systems */
+#undef const
+#endif
+#endif
