@@ -3,20 +3,20 @@
  *									*
  *	Seems to be perfect.						*
  *									*
- *	Copyright (c) 1991-1995, S.R. van den Berg, The Netherlands	*
+ *	Copyright (c) 1991-1999, S.R. van den Berg, The Netherlands	*
  *	#include "../README"						*
  ************************************************************************/
 #ifdef RCS
 static /*const*/char rcsid[]=
- "$Id: regexp.c,v 1.58 1995/05/16 19:56:46 berg Exp $";
+ "$Id: regexp.c,v 1.66 2000/10/23 09:04:25 guenther Exp $";
 #endif
 #include "procmail.h"
 #include "sublib.h"
 #include "robust.h"
 #include "shell.h"
 #include "misc.h"
+#include "variables.h"
 #include "regexp.h"
-#include "goodies.h"
 
 #define R_BEG_GROUP	'('
 #define R_OR		'|'
@@ -174,7 +174,7 @@ static void psimp(e)const struct eps*const e;
 	   goto fine;
 	 }
 	goto fine2;
-     case R_EOL:case R_SOL:		      /* match a newline (in effect) */
+     case R_SOL:			      /* match a newline (in effect) */
 	if(p[1]==R_SOL)
 	 { p++;
 	   if(e)
@@ -182,10 +182,12 @@ static void psimp(e)const struct eps*const e;
 	       goto fine;
 	    }
 	 }
-	else if(e)
-	 { r->opc='\n';
-	   goto fine;
-	 }
+	else
+     case R_EOL:
+	   if(e)
+	    { r->opc='\n';
+	      goto fine;
+	    }
 	goto fine2;
      case R_ESCAPE:					  /* quote something */
 	switch(*++p)
@@ -217,7 +219,7 @@ fine3:
 
 #define EOS(x)	(jj?Ceps e:(x))
 
-static int endgroup(p)register const char*const p;
+static int endgroup(p)register const uchar*const p;
 { switch(*p)
    { case R_OR:case R_END_GROUP:case '\0':
 	return 1;
@@ -529,9 +531,9 @@ pcstack_switch:;				   /* this pc-stack is empty */
 		    case OPC_JUMP-OPB:reg=reg->next;
 		       continue;
 		    case OPC_BOM-OPB:
-		       if(eom)			       /* extended behaviour */
-			  goto setmatch;
-foundbom:	       reg=epso(reg,sizeof(union seps));start=(const char*)str;
+		       if(!eom)
+foundbom:		  start=(const char*)str;
+		       reg=epso(reg,sizeof(union seps));
 		       continue;
 		    case OPC_FILL-OPB:		/* nop, nothing points at it */
 		       if(thiss==Ceps&tswitch)
@@ -586,22 +588,18 @@ wrapup:
       }
 checkmatch:
      if(eom)
-      { static char match[]=MATCHVAR;char*q;
-setmatch:
+      { static const char match[]=MATCHVAR,amatch[]=AMATCHVAR;char*q;
 	if(bom<(char*)text)
 	   bom=(const char*)text;
 	if(eom>--pend)
 	   eom=pend;
-	len=eom-bom;match[STRLEN(match)-1]='\0';
+	len=eom>bom?eom-bom:0;
 	if(getenv(match)==(const char*)text)	     /* anal retentive match */
 	   tmemmove(q=(char*)text,bom,len),q[len]='\0',bom=q;
 	else
 	 { char*p;
-	   match[STRLEN(match)-1]='=';
-	   if(*bom=='\n')
-	      bom++;				/* strip one leading newline */
-	   primeStdout(match);p=realloc(Stdout,(Stdfilled+=len)+1);
-	   tmemmove(q=p+Stdfilled-(int)len,bom,len);retStdout(p);
+	   primeStdout(amatch);p=realloc(Stdout,(Stdfilled+=len)+1);
+	   tmemmove(q=p+Stdfilled-(int)len,bom,len);retbStdout(p);
 	 }
 	yell("Matched",q);
       }
